import { fileURLToPath, URL } from 'node:url'

import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'
import AutoImport from 'unplugin-auto-import/vite'
import Components from 'unplugin-vue-components/vite'
import { ElementPlusResolver } from 'unplugin-vue-components/resolvers'

// https://vite.dev/config/
export default defineConfig({
  envPrefix: ['VITE'],
  plugins: [
    vue(),

    AutoImport({
      resolvers: [ElementPlusResolver()],
    }),
    
    Components({
      resolvers: [ElementPlusResolver()],
    }),
  ],
  resolve: {
    alias: {
      '@': fileURLToPath(new URL('./src', import.meta.url))
    }
  },
  server: {
    host: '127.0.0.1',
    port: 8080, // 端口
    proxy: {
        '/api': { // 请求接口中要替换的标识
            target: 'http://localhost:9080', // 代理地址
            changeOrigin: true, // 是否允许跨域
            secure: true,
            rewrite: (path) => path.replace(/^\/api/, '/api') // api标志替换为''
        }
    }
  }
  
})
